@@ -65,10 +65,17 @@ class Scene(object):
         # do user auth
         username = None
         password = None
+        local = auth.check_local_auth()
         if os.environ.get("ARENA_USERNAME") and os.environ.get("ARENA_PASSWORD"):
+            # auth 1st: use passed in env var
             username = os.environ["ARENA_USERNAME"]
             password = os.environ["ARENA_PASSWORD"]
+        elif local and 'username' in local and 'token' in local:
+            # auth 2nd: use locally saved token
+            username = local["username"]
+            password = local["token"]
         else:
+            # auth 3rd: use the user account online
             username = auth.authenticate_user(self.host, debug=self.debug)
 
         if os.environ.get("NAMESPACE"):
@@ -560,6 +567,14 @@ class Scene(object):
         output = json.loads(data)
         return output
 
+
+    def get_writable_scenes(self):
+        """ Request list of scene names for logged in user account that user has publish permission for.
+        Returns: list of scenes.
+        """
+        return auth.get_writable_scenes(host=self.host, debug=self.debug)
+
+
     def message_callback_add(self, sub, callback):
         """Subscribes to new topic and adds callback"""
         self.mqttc.message_callback_add(sub, callback)
